# hazaj
Example description

## Installation
Run the following to install:

```python
pip install hazaj
```

## Usage
```python
from hazaj import say_hello

# Generate "Hello World!"
say_hello()

# Generate "Hello Everybody!"
say_hello("Everybody")
```